/*
Attribution-NonCommercial-ShareAlike 3.0 (http://creativecommons.org/licenses/by-nc-sa/3.0/us/) + Windfinder Additions

You are free:
* to share - to copy, distribute, display, and perform the work
* to remix - to make derivative works (add new features, make improvements, fix bugs)

Under the following conditions:

* Attribution: You must attribute the work in the manner specified by the author or licensor (but not in any way that suggests that they endorse you or your use of the work).
* Noncommercial: You may not use this work for commercial purposes.
* Share Alike: If you alter, transform, or build upon this work, you may distribute the resulting work only under the same or similar license to this one.

* For any reuse or distribution, you must make clear to others the license terms of this work. The best way to do this is with a link to Windfinder.com.
* Any of the above conditions can be waived if you get permission from the copyright holder.
* Apart from the remix rights granted under this license, nothing in this license impairs or restricts the author's moral rights.

Windfinder Addtions:
* Respect trademark rights: You may not alter the Windfinder logo or remove it from the software.
* Respect data source: You may not change the download source of the weather data that is displayed in the software. The weather data that is displayed in the software has to originate from Windfinder.com. 
* Display limitations: You may not display more than three weather parameters (e.g. wind speed, wind direction, air temperature) in the software 
* No advertising, logos or ad banners from third parties: You may not display advertising,logos or ad banners from companies other than Windfinder.com

*/

/*ms functions to specify settings file and actions for dock/undock*/

System.Gadget.settingsUI = "WindfinderSettings.html";
System.Gadget.onSettingsClosing = SettingsClosing;
System.Gadget.onDock=function() {myDock();};
System.Gadget.onUndock=function() {myUndock();};

/*initialising the gadget*/

function initGadget() {

  if (System.Gadget.docked==true) myDock();
  var mySpot = System.Gadget.Settings.read("mySpot");
    //				ms method of retrieving preferences

	if (mySpot == "") {//if first time launch the widget is initialised with default spot setup

		mySpot="10044";
		var myRegion="17";
		var myCountry="Germany";
		var myContinent="Europe";
		var mySpotLib="Kiel Lighthouse";
		var mySpotKeyword="kiel_lighthouse";
		
		var myWindUnit='kts';
		var myWavesUnit='m';
		var myTempUnit='celcius';
		
		var myVersion = '1.1.3';
		
		var myParams="wind_speed/wind_gusts/wind_direction";		
			
		System.Gadget.Settings.write("mySpot", mySpot);
		System.Gadget.Settings.write("myRegion", myRegion);
		System.Gadget.Settings.write("myCountry", myCountry);
		System.Gadget.Settings.write("myContinent", myContinent);
		System.Gadget.Settings.write("mySpotLib", mySpotLib);
		System.Gadget.Settings.write("mySpotKeyword", mySpotKeyword);
		
		System.Gadget.Settings.write("myParams", myParams);
		
		System.Gadget.Settings.write("myWindUnit", myWindUnit);
		System.Gadget.Settings.write("myWavesUnit", myWavesUnit);
    System.Gadget.Settings.write("myTempUnit", myTempUnit);
    
    System.Gadget.Settings.write("myLastObservation", "");
    System.Gadget.Settings.write("myLastObservationDate", 0);
		System.Gadget.Settings.write("myLastForecast", "");
		System.Gadget.Settings.write("myLastForecastDate", 0);
		System.Gadget.Settings.write("myLastSpotList", "");
		System.Gadget.Settings.write("myLastSpotListMd5", "");
		System.Gadget.Settings.write("myLastSpotListDate", 0);

		}
		//get the latest data and draw the front
		deleteUpdateNotification();
		drawSpotName();
		checkDates();
		
}



function SettingsClosing(event) {
	
	if (event.closeAction == event.Action.commit) {
 	    //redraw things or update data we closing preferences
      drawSpotName();
      if (System.Gadget.Settings.read("myLastObservationDate")>0&&currentObservation) {
         drawObservation();
	       drawForecast();
      } else {
        checkDates();
      }
		  
	}

	event.cancel = false;
}

/*
2 functions to switch between docked/undocked style
*/
function myDock() {
  $('frontDocked').style.display='block';
  $('front').style.display='none';
  document.body.style.width='130px';
  document.body.style.height='190px';
  windfinderBackground.src='frontdocked.png';
  windfinderBackground.style.width='130px';
}
function myUndock() {
  $('frontDocked').style.display='none';
  $('front').style.display='block';
  document.body.style.width='200px';
  document.body.style.height='190px';
  windfinderBackground.src='Default.png';
  windfinderBackground.style.width='200px';
}


function displayFront() {

	drawSpotName();
	drawObservation();
	drawForecast();	
}

/*
date functions :
if no date (first launch) or older than refresh interval then 
get the latest data
+
setinterval functions for continuous checking

*/


function checkDates() {
	checkObservationDate();
	checkForecastDate();
	getServerVersion();
}

var obsInterval=setInterval("checkObservationDate()",600000);
var forecastInterval=setInterval("checkForecastDate()",21600000);

function checkObservationDate() {
	var currentDate=System.Gadget.Settings.read("myLastObservationDate");
	var now=new Date();
	
	if (!currentDate||now.getTime()>currentDate+600000||!currentObservation) { //10 minutes caching or no data
	   getObservation();
	}
}
function checkForecastDate() {
	var currentDate=System.Gadget.Settings.read("myLastForecastDate");
	var now=new Date();
	
	if (!currentDate||now.getTime()>currentDate+21600000||!currentForecast) { //6 hours caching or no data
		getForecast();
	}
}

var currentObservation;
var currentForecast;

/*
get functions, that retrieve functions from the xml interface

xml trees have to be stored in js variables because they exceed MS prefs capacity
*/

function getObservation() {
	var time = new Date();
	var url="http://www.windfinder.com/wind-cgi/xmlreport.pl?CUSTOMER=vista&STATIONS="+System.Gadget.Settings.readString("mySpot").unescapeHTML() + 
			"&timestamp=" + time.getTime();
	new Ajax.Request(url,{method:'get', parameters: time.getTime(), onSuccess: function(t){onGetObservation(t);},onFailure:function(){observationError();}});
}
function onGetObservation(xml) {
    currentObservation=xml.responseXML;
	var now=new Date();
	System.Gadget.Settings.write("myLastObservationDate",now.getTime());
	drawObservation(xml.responseXML);
}
function getForecast() {
	var time = new Date();
	var url="http://www.windfinder.com/wind-cgi/xmlforecast.pl?CUSTOMER=vista&STATIONS="+System.Gadget.Settings.readString("mySpot").unescapeHTML() + 
			"&timestamp=" + time.getTime();
	new Ajax.Request(url,{method:'get', onSuccess: function(t){onGetForecast(t);},onFailure:function(){forecastError();}});
}
function onGetForecast(xml) {
  currentForecast=xml.responseXML;
	var now=new Date();
	System.Gadget.Settings.write("myLastForecastDate",now.getTime());
	drawForecast(xml.responseXML);
}

function getServerVersion() {
	var url="http://www.windfinder.com/widget/vista.json";
	var time = new Date();
	new Ajax.Request(url,{method:'post', parameters: time.getTime(), onSuccess: function(t){onGetServerVersion(t);},onFailure:function(){}});
}

function onGetServerVersion(xml) {
	var response = eval('(' + xml.responseText + ')');
	
	if (response.version) {
		if (updateAvailable(response.version)) {
			// print update notification
			printUpdateNotification(response.file);
		}
	}
}

function printUpdateNotification(url) {
	var templib = getLocalizedString("updateHelpText");
	var link = "<a title=\""+ templib +"\" href=\""+ url +"\">"
								+getLocalizedString("updateAvailable")+"</a>"

	$('updateNotificationDocked').innerHTML = link;
	$('updateNotificationUndocked').innerHTML = link;
}

function deleteUpdateNotification() {
	$('updateNotificationDocked').innerHTML = "";
	$('updateNotificationUndocked').innerHTML = "";
}

/*
draws the spot name and other stuff.
*/

function drawSpotName() {
	var spotID=System.Gadget.Settings.read("mySpotKeyword");
	var templib=getLocalizedString("Click for the full reports and forecasts on windfinder.com").unescapeHTML();
	

	$('libSpot').innerHTML=System.Gadget.Settings.read("mySpotLib");
	$('libObservations').innerHTML="<a title=\""+templib+"\" href=\"http://www.windfinder.com/report/"+spotID+"\">"+getLocalizedString("Observation")+"</a>";
	$('libForecast').innerHTML="<a title=\""+templib+"\" href=\"http://www.windfinder.com/forecast/"+spotID+"\">"+getLocalizedString("Forecast")+"</a>";
	
	$('libSpotDocked').innerHTML=	$('libSpot').innerHTML;

	
	var longueur=$('libSpot').innerHTML.unescapeHTML().length;
	if (longueur>20) {
		if (longueur>30) {
			$('libSpot').style.setAttribute("cssText","font-size:10px;");
			$('libSpotDocked').style.setAttribute("cssText","font-size:10px;");
			$('feedBack').innerHTML='very small';
		} else {
			$('libSpot').style.setAttribute("cssText","font-size:12px;");
			$('libSpotDocked').style.setAttribute("cssText","font-size:12px;");
			$('feedBack').innerHTML='small';
		}
	} else {

		$('libSpot').style.setAttribute("cssText","");
		$('libSpotDocked').style.setAttribute("cssText","");
	}
	
	
	$('libObservationsDocked').innerHTML=$('libObservations').innerHTML;
	
	$('libDate').innerHTML=getLocalizedString("Date");
	$('libTime').innerHTML=getLocalizedString("Time");
	
	$('libDateDocked').innerHTML=	$('libDate').innerHTML;
	$('libTimeDocked').innerHTML=$('libTime').innerHTML;
	
	wfAd();
	var currentParams=System.Gadget.Settings.read("myParams").split("/");
	var nbParams=currentParams.length;
	for(var i=0;i<nbParams;i++) {
	   var tempHTML='';
	  switch(currentParams[i]) {
      case 'wind_speed':
        tempHTML=getLocalizedString("wind speed");
        break;
      case 'wind_gusts':
        tempHTML=getLocalizedString("wind gust");
        break;
      case 'wind_direction':
        tempHTML=getLocalizedString("wind dir.");
        break;
      case 'wave_height':
        tempHTML=getLocalizedString("waves height");
        break;
      case 'wave_direction':
        tempHTML=getLocalizedString("waves dir.");
        break;
      case 'wave_period':
        tempHTML=getLocalizedString("waves period");
        break;
      case 'air_temperature':
        tempHTML=getLocalizedString("air temp.");
        break;
      case 'water_temperature':
        tempHTML=getLocalizedString("water temp.");
        break;
      case 'air_pressure':
        tempHTML=getLocalizedString("pressure sealevel");
        break;
      case 'clouds':
        tempHTML=getLocalizedString("clouds");
        break;
      case 'precipitation':
        tempHTML=getLocalizedString("precipitation");
        break;       
      default:
        tempHTML=currentParams[i];
      }
     $('libParam'+(i+1)).innerHTML=tempHTML.capitalize();
     $('libParam'+(i+1)+'Docked').innerHTML=$('libParam'+(i+1)).innerHTML;
     
 		var smallclass='';
		var temp=$('libParam'+(i+1)).innerHTML.unescapeHTML();
		if (temp.length>12) smallclass=' smallParamsFont';
		$('libParam'+(i+1)).setAttribute('className','whiteBg tdBorderParamsBas'+smallclass);
		$('libParam'+(i+1)+'Docked').setAttribute('className','whiteBg tdBorderParamsBas'+smallclass);
	
		if (currentParams[i]=="wind_direction"||currentParams[i]=="wave_direction") {
			$('libParam'+(i+1)).setAttribute('height','19px');
			$('libParam'+(i+1)+'Docked').setAttribute('height','19px');
		} else {
			$('libParam'+(i+1)).setAttribute('height','15px');
			$('libParam'+(i+1)+'Docked').setAttribute('height','15px');
			
		}
  }
  for(var j=i;j<3;j++) {
    $('libParam'+(j+1)).innerHTML="";
    $('libParam'+(j+1)+'Docked').innerHTML="";
    $('libParam'+(j+1)).setAttribute('className','');
		$('libParam'+(j+1)+'Docked').setAttribute('className','');
  }
  
}

/*
functions that control mousescroll and clicking on arrows
*/


function mymouseWheelMove() {
	var clicks = Math.round(window.event.wheelDelta);
	var curr=$('contentForecast').style.left.split("px");
	curr=Math.round(curr[0]);
	var move=curr+clicks;

	if (clicks<0) {
		if (curr<0) {
		    $('contentForecast').style.left=(curr+5)+"px";
		}
	} else {
		if (curr>-300) {
	     	$('contentForecast').style.left=(curr-5)+"px";
		}
	}
}

function previousForecast() {
	var curr=$('contentForecast').style.left.split("px");
	curr=Math.round(curr[0]);
	var move=curr+25;
	if (move>0) move=0;
	if (curr<0) $('contentForecast').style.left=move+"px";
}
function nextForecast() {
	var curr=$('contentForecast').style.left.split("px");
	curr=Math.round(curr[0]);
	var move=curr-25;
	if (move<-300) move=-300;	
	if (curr>-300) $('contentForecast').style.left=move+"px";
}


/*
drawing the observation column
*/

function drawObservation(xmlTree) {

	if (!xmlTree) {
		//the function can be called with an xml tree (when used with fresh data)
  	//or it uses the stored xml tree
  	xmlTree = currentObservation;
	}
	var tempHTML="";

	var observation=xmlTree.getElementsByTagName('station');
	var noreport=false;
	tempHTML+='<table width="25px" cellspacing="0" cellpadding="0" class="tdBorder">';
	
	if (observation.length>0&&observation[0].hasChildNodes()) {//tests to draw only if data is complete
		var currentParams=System.Gadget.Settings.read("myParams").split("/");
		var nbParams=currentParams.length;
		
		var mydate=xmlTree.getElementsByTagName('date');
		
		if (mydate.length>0) {
		
		    /*date and time*/
    		var mytime=xmlTree.getElementsByTagName('time');
    		tempHTML+='<tr><td class="greyBg">';
    		tempHTML+=wfDate(mydate[0].firstChild.nodeValue);
    		tempHTML+='</td></tr>';
    		tempHTML+='<tr><td class="greyBg">';
    		tempHTML+=wfHour(mytime[0].firstChild.nodeValue);
    		tempHTML+='</td></tr>';
    		
    		/*for each user param, display the data*/
      	for (var j=0;j<nbParams;j++) {
        			var temp=observation[0].getElementsByTagName(currentParams[j]);
        			if (temp.length>0) {
        				if (temp[0].hasChildNodes()) {
						    var test = temp[0].childNodes[0].nodeValue;
        					tempHTML+=wfCell(currentParams[j],temp[0].childNodes[0].nodeValue);
        				} else {
        					tempHTML+=wfEmptyCell(currentParams[j]);
        				}
        			} else {
        					tempHTML+=wfEmptyCell(currentParams[j]);
        			}
      		}		    
    } else {
      noreport=true;

  	}
	} else {
	   noreport=true;
  }
  if (noreport==true) {
  	observationError();
  } else {
    tempHTML+='</table>';
  	$('contentObservations').innerHTML=tempHTML;
  	$('contentObservationsDocked').innerHTML=tempHTML;  
  }

	tempHTML+='</table>';

}

function getTableHeight() {
	var tempH=30;
	var currentParams=System.Gadget.Settings.read("myParams").split("/");
	var nbParams=currentParams.length;
	for (var i=0;i<nbParams;i++) {
		if (currentParams[i]=="wind_direction"||currentParams[i]=="wave_direction") {
			tempH+=19;
		} else {
			tempH+=15;
		}
	}
	return tempH+3;
}
function setObservationHeight() {
	if ($('divnoreport')||$('divnoforecast')) {
		var tempH=getTableHeight();
		if ($('divnoreport')&&tempH) {
			$('divnoreport').style.setAttribute('cssText','height:'+tempH+'px');
			$('divnoreport2').style.setAttribute('cssText','height:'+tempH+'px');
		}
		if ($('divnoforecast')&&tempH) {
			$('divnoforecast').style.setAttribute('cssText','height:'+tempH+'px');
		}		
		
	}
}
function observationError() {
	var tempHTML="";
	tempHTML+='<table width="25px" cellspacing="0" cellpadding="0" class="noreportBorder">';
	tempHTML+='<tr><td width="25px"><div class="noReport" id="divnoreport">'+getLocalizedString('No report available')+'</div></td></tr>';
	tempHTML+='</table>';
	$('contentObservations').innerHTML=tempHTML;
	tempHTML='<table width="25px" cellspacing="0" cellpadding="0" class="noreportBorder">';
	tempHTML+='<tr><td width="25px"><div class="noReport" id="divnoreport2">'+getLocalizedString('No report available')+'</div></td></tr>';
	tempHTML+='</table>';	
	$('contentObservationsDocked').innerHTML=tempHTML;
	setObservationHeight(); //this function is called to fix height issues between labels, report and forecast
}

function forecastError() {

	var tempHTML='<div class="noReport" id="divnoforecast">'+getLocalizedString('No forecast available')+'</div>';
	$('contentForecast').innerHTML=tempHTML;

	setObservationHeight();
}


function drawForecast(xmlTree) {
	/*this function does the same thing as drawObservations, but for several dates
	*/

	if (!xmlTree) {	
		xmlTree = currentForecast;
	}	
	
	var tempHTML="";

	var forecasts=xmlTree.getElementsByTagName('forecast');
	if (forecasts.length>0) {
		var currentParams=System.Gadget.Settings.read("myParams").split("/");
		var nbParams=currentParams.length;
		if (forecasts[0].getAttribute('date')!="") {
		
    		tempHTML+='<table border="0" cellspacing="0" cellpadding="0">';
    		tempHTML+='<tr>';
    		
    		var timeZone=xmlTree.getElementsByTagName('station');
			   timeZone=parseFloat(timeZone[0].getAttribute('timezone'));
    		
    		for (var i=0;i<forecasts.length;i++) {
    			tempHTML+='<td>';
    			var tempNode=forecasts[i];
    			tempHTML+='<table cellspacing="0" cellpadding="0" class="tdBorder">';
    			tempHTML+='<tr><td class="greyBg">';
    			tempHTML+=wfDate(tempNode.getAttribute('date'));
    			tempHTML+='</td></tr>';
    			tempHTML+='<tr><td class="greyBg">';
    			tempHTML+=wfHour(tempNode.getAttribute('time'));
    			tempHTML+='</td></tr>';		
    			
    			if (i==0) {
    					//for the first forecast slot convert to a valid date object
    					var tempDate=tempNode.getAttribute('date');
    					var tempTime=tempNode.getAttribute('time');
    					var beginForecastLocalTime=new Date(tempDate.substr(0,4),(parseFloat(tempDate.substr(4,2))-1),tempDate.substr(6,2),wfHour(tempTime));
			   	}
    			
    			for (var j=0;j<nbParams;j++) {
    					var temp=tempNode.getElementsByTagName(currentParams[j]);
    					if (temp.length>0) {
    						if (temp[0].hasChildNodes()) {
    							tempHTML+=wfCell(currentParams[j],temp[0].childNodes[0].nodeValue);
    						} else {
    							tempHTML+=wfEmptyCell(currentParams[j]);
    						}
    					} else {
    						tempHTML+=wfEmptyCell(currentParams[j]);
    					}
    			}
    			tempHTML+='</table>';
			    tempHTML+='</td>';
    		}
    		
			tempHTML+='</tr>';
			tempHTML+='</table>';
			$('contentForecast').innerHTML=tempHTML;
			
			var now=new Date();
			now.setHours(now.getUTCHours()+timeZone);//current local time
			var offset=Math.round((now.getTime()-beginForecastLocalTime.getTime())/(3*1000*3600))+1;
			if (offset<13&&offset>0) $('contentForecast').style.left=(-offset*25)+"px";
			
			
		} else {
			forecastError();
		}
		
	} else {
		forecastError();
	}
	
}


function wfDate(string) {
	return string.substr(6);
}
function wfHour(string) {
	return string.substr(0,2);
}
function wfVertical(string) {
	var nb=string.length;
	var tempHTML="";
	for (var i=0;i<nb;i++) {
		tempHTML+=string[i]+'<br/>';
	} 
	
	return tempHTML;
}

function wfEmptyCell(typeVal) {
	var tempHTML="";	
	if (typeVal=="wind_direction"||typeVal=="wave_direction") {
		tempHTML+="<tr height=\"18px;\"><td height='18px;' class='whiteBg'>n/a</td></tr>";
	} else {
		tempHTML+="<tr><td class='whiteBg'>n/a</td></tr>";
	}
	return tempHTML;
}
/*this function splits a string (BKN CLR..) to readable string for alt or title */
function getAltTags(tags) {
	var tags=tags.split(" ");
	var tempHTML="";
	var nbTags=tags.length;
	if (nbTags>0) {
		for (var i=0;i<nbTags;i++) {
			tempHTML+=getLocalizedString(tags[i]+"_alt")+" ";
		}
	}
	return tempHTML;
}

/*
this is one of the main functions, that converts data to cells with colors and symbols

*/
function wfCell(typeVal,myvalue) {
	var tempHTML="";

	tempHTML+="<tr>";
	switch(typeVal) {
		case "air_temperature":
			var temp=Math.round(myvalue/2)+7;
			if (temp>26) temp=26;
			if (temp<=0) temp=0;
			if (System.Gadget.Settings.read("myTempUnit")=='fahrenheit') {
				myvalue=32+(9*myvalue)/5;
			}
			var alarm=parseFloat(System.Gadget.Settings.read("myTempAlarm"));
			if (alarm>0&&parseFloat(myvalue)>=alarm) {
				temp+=" windAlarm";
			}	
			tempHTML+='<td class="ws'+temp+'">'+Math.round(myvalue)+'</td>';	
			break;
		case "wind_speed":
			
			var temp=Math.round(myvalue/2);
			if (temp>26) temp=26;
			var myUnit=System.Gadget.Settings.read("myWindUnit");
			switch(myUnit)  {
				case 'bft':
					var bft=0;
					if (myvalue>=0.6) bft = 1;if (myvalue>=3) bft = 2;if (myvalue>=7) bft = 3;if (myvalue>=11) bft = 4;if (myvalue>=16) bft = 5;
					if (myvalue>=21) bft = 6;if (myvalue>=27) bft = 7;if (myvalue>=33) bft = 8;if (myvalue>=40) bft = 9;if (myvalue>=47) bft = 10;if (myvalue>=55) bft = 11;if (myvalue>=64) bft = 12;
					myvalue=bft;
					break;
				case 'ms':
					myvalue=0.514444*myvalue;
					break;
				case 'kmh':
					myvalue=3.6*0.514444*myvalue;
					break;
				default :
					break;
			}
			var alarm=parseFloat(System.Gadget.Settings.read("myWindAlarm"));
			if (alarm>0&&parseFloat(myvalue)>=alarm) {
				temp+=" windAlarm";
			}
			myvalue=Math.round(myvalue);
			tempHTML+='<td class="ws'+temp+'">'+myvalue+'</td>';	
			break;	
		case "wind_direction":
			myvalue=myvalue.toLowerCase();
			tempHTML+='<td class="whiteBg"><img src="./arrows/dir-'+myvalue+'.png"/></td>';	
			break;
		case "wave_height":
			myvalue=parseFloat(myvalue);
			var temp=0;
			if (myvalue>0.1) temp=1;if (myvalue>0.3) temp=2;if (myvalue>0.5) temp=3;if (myvalue>0.9) temp=4;if (myvalue>1.2) temp=5;if (myvalue>1.5) temp=6;if (myvalue>2) temp=7;if (myvalue>2.5) temp=8;
			if (myvalue>3) temp=Math.round(myvalue)+6;
			if (myvalue>12) temp=17;
			
			if  (System.Gadget.Settings.read("myWavesUnit")=="m") {
				myvalue=Math.round(10*myvalue)/10;
			} else {
				myvalue=Math.round(3.2808399*myvalue);
			}
			var alarm=parseFloat(System.Gadget.Settings.read("myWaveAlarm"));
			if (alarm>0&&parseFloat(myvalue)>=alarm) {
				temp+=" windAlarm";
			}	
			
			tempHTML+='<td class="wh'+temp+'">'+myvalue+'</td>';	
			break;
		case "wave_direction":alert('wave dir');
			myvalue=parseFloat(myvalue);alert(myvalue);
			var temp='n';
			myvalue=Math.round(myvalue/22.5);alert(myvalue);
			if (myvalue==1) temp='nne';if (myvalue==2) temp='ne';if (myvalue==3) temp='ene';if (myvalue==4) temp='e';
			if (myvalue==5) temp='ese';if (myvalue==6) temp='se';if (myvalue==7) temp='sse';if (myvalue==8) temp='s';
			if (myvalue==9) temp='ssw';if (myvalue==10) temp='sw';if (myvalue==11) temp='wsw';if (myvalue==12) temp='w';
			if (myvalue==13) temp='wnw';if (myvalue==14) temp='nw';if (myvalue==15) temp='nnw';
			
			tempHTML+='<td class="whiteBg"><img src="./arrows/dir-'+temp+'.png"/></td>';
			break;
    case "wave_period":
			var temp='';
			var alarm=parseFloat(System.Gadget.Settings.read("myWavePeriodAlarm"));
			if (alarm>0&&parseFloat(myvalue)>=alarm) {
				temp+=" windAlarm";
			}	
			tempHTML+='<td class="whiteBg'+temp+'">'+myvalue+'</td>';
			break;		
		case "clouds":
			var image ='blank';
			var initval=myvalue;
			switch(myvalue) {
				case "CLR" :
					image="skc.gif";
				default:
					myvalue =myvalue.split(" ");
					
					image=myvalue[0].toLowerCase()+".gif";
			}
			tempHTML+='<td height="15" class="whiteBg"><img title="'+getAltTags(initval)+'" src="./symbols/'+image+'"/></td>';
			break;			
		case "precipitation":
			myvalue=parseFloat(myvalue);
			var temp=Math.round(myvalue);
			if (temp>15) temp=15;
			myvalue=Math.round(myvalue);
			tempHTML+='<td class="ra'+temp+'">'+myvalue+'</td>';	
			break;				
		case "weather" :
			var image ='blank';
			switch(myvalue) {
				default:
					myvalue =myvalue.split(" ");
					image=myvalue[0].toLowerCase()+".gif";
					break;
			}		
			tempHTML+='<td height="15" class="whiteBg"><img src="./symbols/'+image+'"/></td>';
			break;			
		default :
			tempHTML+='<td class="whiteBg">'+myvalue+'</td>';	
			break;
			
	}
	tempHTML+="</tr>";
	return tempHTML;
}


function wfAd() {
/*	var id=312; var jar=new Date();var s=jar.getSeconds();var m=jar.getMinutes();
	var flash=s*m+id;var cgi='http://www.windfinder.com/wind-cgi/adcycle';
	var p='<a href="'+cgi+'/adclick.cgi?gid=12&id='+flash+'">';
	p+='<img src="'+cgi+'/adcycle.cgi?gid=12&id='+flash+'" width=180 height=40 ';
	p+='border=0 alt="Click to Visit"></a>';
	$('adsContainer').innerHTML=p;*/
}
