/*
Attribution-NonCommercial-ShareAlike 3.0 (http://creativecommons.org/licenses/by-nc-sa/3.0/us/) + Windfinder Additions

You are free:
* to share - to copy, distribute, display, and perform the work
* to remix - to make derivative works (add new features, make improvements, fix bugs)

Under the following conditions:

* Attribution: You must attribute the work in the manner specified by the author or licensor (but not in any way that suggests that they endorse you or your use of the work).
* Noncommercial: You may not use this work for commercial purposes.
* Share Alike: If you alter, transform, or build upon this work, you may distribute the resulting work only under the same or similar license to this one.

* For any reuse or distribution, you must make clear to others the license terms of this work. The best way to do this is with a link to Windfinder.com.
* Any of the above conditions can be waived if you get permission from the copyright holder.
* Apart from the remix rights granted under this license, nothing in this license impairs or restricts the author's moral rights.

Windfinder Addtions:
* Respect trademark rights: You may not alter the Windfinder logo or remove it from the software.
* Respect data source: You may not change the download source of the weather data that is displayed in the software. The weather data that is displayed in the software has to originate from Windfinder.com. 
* Display limitations: You may not display more than three weather parameters (e.g. wind speed, wind direction, air temperature) in the software 
* No advertising, logos or ad banners from third parties: You may not display advertising,logos or ad banners from companies other than Windfinder.com

*/

// holds the current md5 hash of the station list
var currentMD5Hash;
var currentSpotList;

// name of the station list file in cache
var STATIONLIST_NAME = "stations.xml";

function initSettings() {
  $('feedBackSettings').innerHTML='initSettings';
  initPrefsHTML();
}
function getSpotList() {
    var url="http://www.windfinder.com/wind-cgi/xmlstations.pl?CUSTOMER=vista";
	new Ajax.Request(url,{method:'post',onSuccess: function(t){onGetSpotList(t);},onFailure: function(t){spotListError(t);}});
}
function spotListError(xml) {
  $('libSpotPrefs_content').innerHTML=getLocalizedString("Server unreachable");
}
function onGetSpotList(mxml) {

  currentSpotList=mxml.responseXML;
  
  // station list request was succesful
  // save the former requested matching md5 hash
  System.Gadget.Settings.writeString("myLastSpotListMD5", currentMD5Hash);
  
	var now=new Date();
	System.Gadget.Settings.write("myLastSpotListDate",now.getTime());
	
	// write new station list to cache
	writeToCache(STATIONLIST_NAME, currentSpotList.xml);

  drawSpotList(mxml.responseXML);

}

function getSpotListMD5() {
	$('libSpotPrefs_content').innerHTML=getLocalizedString("Retrieving spot list...");
	var url = "http://www.windfinder.com/windfox/stations.md5";
	new Ajax.Request(url,{method:'post',onSuccess: function(t){onGetSpotListMD5(t);},onFailure: function(t){spotListMD5Error(t);}});
}

function onGetSpotListMD5(mxml) {
	
	var currentMD5 = mxml.responseXML;
		
	// if there is no station list and md5 hash in settings store
	// save the new md5 hash and request a new station list
	if (!fileExistsInCache(STATIONLIST_NAME) || 
	    !System.Gadget.Settings.readString("myLastSpotListMD5")) {
	   currentMD5Hash = currentMD5.text;
	   getSpotList();
	}
	// requested md5 hash and stored one are different, so request new station list
	else if (System.Gadget.Settings.readString("myLastSpotListMD5") != currentMD5.text) {
	    currentMD5Hash = currentMD5.text;
		getSpotList();
	}
	// station list nor md5 hash has changed, so draw spot list with stored station list
	else {
	   var stationList = currentSpotList = buildDOM(readFromCache(STATIONLIST_NAME));
	   drawSpotList(stationList);
	}

}

function spotListMD5Error(xml) {
    // keine Stationsliste da
	if (!System.Gadget.Settings.read("mySpotList")) {
	   $('libSpotPrefs_content').innerHTML=getLocalizedString("Server unreachable");
	}
	else {
	   var stationList = currentSpotList = buildDOM(readFromCache(STATIONLIST_NAME));
	   drawSpotList(stationList);
	}
}

function initPrefsHTML() {
	
		$('feedBackSettings').innerHTML='first settings';
		//draw spot list if available :
		if (System.Gadget.Settings.read("myLastSpotList")=='') {
      	$('feedBackSettings').innerHTML='no spot list available';
    }
		
		$('libSpotPrefs').innerHTML=getLocalizedString("Weather Station");
		$('libParamsPrefs').innerHTML=getLocalizedString("Display");
		$('libParamsUnits').innerHTML=getLocalizedString("Measuring units");	
		$('libParamsAlarm').innerHTML=getLocalizedString("Alarm");	
		
    $('libParamsPrefs_sub').innerHTML=getLocalizedString("Select up to 3 parameters");
		$('libParamsUnits_sub').innerHTML=getLocalizedString("Select units of measurement");
		$('libParamsAlarm_sub').innerHTML=getLocalizedString("Select threshold for selected parameters");
     	
    $('libParams1').innerHTML=getLocalizedString("wind speed");
		$('libAlarm1').innerHTML=$('libParams1').innerHTML;
		$('libParams2').innerHTML=getLocalizedString("wind gust");
		$('libParams3').innerHTML=getLocalizedString("wind dir.");
		$('libParams4').innerHTML=getLocalizedString("waves height");
		$('libAlarm2').innerHTML=$('libParams4').innerHTML;
		$('libParams5').innerHTML=getLocalizedString("waves dir.");
		$('libParams6').innerHTML=getLocalizedString("waves period");
		$('libAlarm3').innerHTML=$('libParams6').innerHTML;
		$('libParams7').innerHTML=getLocalizedString("air temp.");
		$('libAlarm4').innerHTML=$('libParams7').innerHTML;

		$('libParams9').innerHTML=getLocalizedString("pressure sealevel");	
		$('libParams10').innerHTML=getLocalizedString("clouds");	
		$('libParams8').innerHTML=getLocalizedString("precipitation");
		
		drawParams();
		
		$('libUnitsWind1').innerHTML=getLocalizedString("Knots");
		$('libUnitsWind2').innerHTML=getLocalizedString("Bft");
		$('libUnitsWind3').innerHTML=getLocalizedString("m/s");
		$('libUnitsWind4').innerHTML=getLocalizedString("km/h");
		$('libUnitsWaves1').innerHTML=getLocalizedString("Meters");
		$('libUnitsWaves2').innerHTML=getLocalizedString("Feet");
		$('libUnitsTemp1').innerHTML=getLocalizedString("&deg;C");
		$('libUnitsTemp2').innerHTML=getLocalizedString("&deg;F");	
		
		$('alarm3Unit').innerHTML=getLocalizedString("Seconds");
		drawUnits();

	 drawAlarms();
	 
	 
}

function drawSpotList(xmlTree) {
  $('feedBackSettings').innerHTML='drawSpotList()';
  if (!xmlTree) xmlTree=currentSpotList;
	var tempHtml='<div id="libSpotPrefs_sub" class="sousTitres">'+getLocalizedString("Select a location")+'</div>';
	
	var continents=xmlTree.getElementsByTagName('continent');
	var nbContinents=Math.round(continents.length);	
	var nContinent=0;
	tempHtml+="<select id='selectContinent' onChange='setContinent(this)'>";		//drawing continents list
	var currid=System.Gadget.Settings.read("myContinent").unescapeHTML();
	for (var i=0;i<nbContinents;i++) {
		var tempselected='';
		var tempid=continents[i].getAttribute('id').unescapeHTML();
		if (tempid==currid) {
			tempselected=' selected';
			nContinent=i;
		}
		tempHtml+="<option value='"+tempid+"'"+tempselected+">"+continents[i].getAttribute('name')+"</option>";
	}
	tempHtml+="</select>";
	tempHtml+="<br/>";

	var countries=continents[nContinent].getElementsByTagName('country');
	var nbCountries=Math.round(countries.length);
	var nCountry=0;
	tempHtml+="<select id='selectCountry' onChange='setCountry(this)'>";
	if(!System.Gadget.Settings.read("myCountry"))  {
	   System.Gadget.Settings.write("myCountry",countries[0].getAttribute('id'));
	}
	var currid=System.Gadget.Settings.read("myCountry").unescapeHTML();
	for (var i=0;i<nbCountries;i++) {
		var tempselected='';
		var tempid=countries[i].getAttribute('id').unescapeHTML();
		if (tempid==currid) {
			tempselected=' selected';
			nCountry=i;
		}
		tempHtml+="<option value='"+tempid+"'"+tempselected+">"+countries[i].getAttribute('name')+"</option>";
	}
	tempHtml+="</select>";

	var regions=countries[nCountry].getElementsByTagName('region');
	var nbRegions=Math.round(regions.length);
	var nRegion=0;
	if(!System.Gadget.Settings.read("myRegion"))  {//alert('default myRegion');
	   System.Gadget.Settings.write("myRegion",regions[0].getAttribute('id').unescapeHTML());
	}
	var currid=System.Gadget.Settings.read("myRegion").toString().unescapeHTML();
	tempHtml+="<select onChange='setRegion(this)'>";
	for (var i=0;i<nbRegions;i++) {
	 $('feedBackSettings').innerHTML='test region '+i;
		var tempselected='';
		var tempid=regions[i].getAttribute('id').unescapeHTML();
		$('feedBackSettings').innerHTML='test region '+tempid;
		if (tempid==currid) {
			tempselected=' selected';
			nRegion=i;
		}
		tempHtml+="<option value='"+tempid+"'"+tempselected+">"+regions[i].getAttribute('name')+"</option>";
	}
	tempHtml+="</select>";	
	tempHtml+="<br/>";
	var stations=regions[nRegion].getElementsByTagName('station');
	var nbSpots=Math.round(stations.length);
	if(!System.Gadget.Settings.read("mySpot"))  {//alert('default mySpot');
	   System.Gadget.Settings.write("mySpot",stations[0].getAttribute('id'));
	   System.Gadget.Settings.write("mySpotLib",stations[0].getAttribute('name'));
	   System.Gadget.Settings.write("mySpotKeyword",stations[0].getAttribute('keyword'));
	   
	   // quick 'n dirty fix of the "Chios"-Bug (minimal invasive - not beautiful, but effective)
	   // set both setting values to zero to force weather update after closing the options menu
	   System.Gadget.Settings.write("myLastObservationDate", 0);
       System.Gadget.Settings.write("myLastForecastDate", 0);
	   
		
	}		
	var currid=System.Gadget.Settings.read("mySpot").toString().unescapeHTML();
	tempHtml+="<select id='selectSpot' onChange='setSpot(this)'>";
	for (var i=0;i<nbSpots;i++) {
		var tempselected='';
		var tempid=stations[i].getAttribute('id').unescapeHTML();
		if (tempid==currid) {
			tempselected=' selected';
			
		}		
		tempHtml+="<option value='"+tempid+"' name='"+stations[i].getAttribute('keyword')+"'"+tempselected+">"+stations[i].getAttribute('name')+"</option>";
	}
	tempHtml+="</select>";	
	tempHtml+="<br/>";
	$('libSpotPrefs_content').innerHTML=tempHtml;

}

/*the set functions below are fired when user changes things in the spot list*/

function setContinent(params) {

 System.Gadget.Settings.write("myContinent",params.value);
 System.Gadget.Settings.write("myCountry","");
 System.Gadget.Settings.write("myRegion","");
 System.Gadget.Settings.write("mySpot","");
	drawSpotList();
}
function setCountry(params) {
 System.Gadget.Settings.write("myCountry",params.value);
 System.Gadget.Settings.write("myRegion","");
 System.Gadget.Settings.write("mySpot","");
	drawSpotList();
}
function setRegion(params) {
 System.Gadget.Settings.write("myRegion",params.value);
 System.Gadget.Settings.write("mySpot","");
	drawSpotList();
}
function setSpot(params) {
  
  System.Gadget.Settings.write("mySpot",params.value);
  System.Gadget.Settings.write("myLastObservationDate", 0);
  System.Gadget.Settings.write("myLastForecastDate", 0);

	var nb=$('selectSpot').childNodes.length;
	var tempid=params.value.unescapeHTML();
	for (var i=0;i<nb;i++) {
		if ($('selectSpot').childNodes[i].getAttribute('value').unescapeHTML()==tempid) {
		  System.Gadget.Settings.write("mySpotLib", $('selectSpot').childNodes[i].innerHTML);
		  System.Gadget.Settings.write("mySpotKeyword", $('selectSpot').childNodes[i].getAttribute('name'));
			break;
		}
	}

}
/*
drawing functions for the units, parameters and alarm
*/
var maxParams=3;
function drawUnits() {
	var windunit=System.Gadget.Settings.read("myWindUnit");
	var wavesunit=System.Gadget.Settings.read("myWavesUnit");
	var tempunit=System.Gadget.Settings.read("myTempUnit");
	
	var nbwinds=4;
	for (var i=1;i<nbwinds+1;i++) {
		if ($('libUnitsWind'+i).getAttribute('value')==windunit) {
			$('libUnitsWind'+i).selected=true;
			$('alarm1Unit').innerHTML=$('libUnitsWind'+i).innerHTML;
		} else {
			$('libUnitsWind'+i).selected=false;
		}
	}
	var nbtemp=2;
	for (var i=1;i<nbtemp+1;i++) {
		if ($('libUnitsWaves'+i).getAttribute('value')==wavesunit) {
			$('libUnitsWaves'+i).selected=true;
			$('alarm2Unit').innerHTML=$('libUnitsWaves'+i).innerHTML;
		} else {
			$('libUnitsWaves'+i).selected=false;
		}
	}	
	var nbwaves=2;
	for (var i=1;i<nbwaves+1;i++) {
		if ($('libUnitsTemp'+i).getAttribute('value')==tempunit) {
			$('libUnitsTemp'+i).selected=true;
			$('alarm4Unit').innerHTML=$('libUnitsTemp'+i).innerHTML;
		} else {
			$('libUnitsTemp'+i).selected=false;
		}
	}	
}

function drawAlarms() {
	var alarm=parseFloat(System.Gadget.Settings.read("myWindAlarm"));
	if (alarm&&alarm!=0) {
		$('alarm1Check').checked=true;
		$('alarm1Field').value=alarm;
	}
	var alarm=parseFloat(System.Gadget.Settings.read("myWaveAlarm"));
	if (alarm&&alarm!=0) {
		$('alarm2Check').checked=true;
		$('alarm2Field').value=alarm;
	}	
	var alarm=parseFloat(System.Gadget.Settings.read("myWavePeriodAlarm"));
	if (alarm&&alarm!=0) {
		$('alarm3Check').checked=true;
		$('alarm3Field').value=alarm;
	}		
	var alarm=parseFloat(System.Gadget.Settings.read("myTempAlarm"));
	if (alarm&&alarm!=0) {
		$('alarm4Check').checked=true;
		$('alarm4Field').value=alarm;
	}		
}

function drawParams() {
	var currentParams=System.Gadget.Settings.read("myParams").split("/");
	
	var nbParams=currentParams.length;
	

	for(var j=1;j<11;j++) {
		$('param'+j).checked=false;
	}
		
	for(var i=0;i<nbParams;i++) {
		
		for(var j=1;j<11;j++) {
			if ($('param'+j).getAttribute('value')==currentParams[i]) {
				$('param'+j).checked=true;

			}
		}
		
	}
}
function updateDisplays(inputObject) {// this fires when user changes the params to be displayed
	var currentParams=System.Gadget.Settings.read("myParams").split("/");
	if (inputObject.checked==false) {
		currentParams=currentParams.without(inputObject.value);
	} else {
		if (currentParams.length<maxParams) {
			currentParams[currentParams.length]=inputObject.value;
		} else {
			currentParams[2]=inputObject.value;
		}
	}
	if (currentParams.length>0) {
	   System.Gadget.Settings.write("myParams",currentParams.join("/"));
	}
	drawParams();
}

function updateWindUnit(object) {
	var alarm=parseFloat(System.Gadget.Settings.read("myWindAlarm"));
	
	if (alarm) alarm=myunit2knots(alarm);
	System.Gadget.Settings.write("myWindUnit",object.value);
	if (alarm) {
		alarm=knots2myunit(alarm);
		System.Gadget.Settings.write("myWindAlarm",alarm);
		$('alarm1Field').value=alarm;
	}
	updateLibUnitAlarm1();
}
function updateLibUnitAlarm1() {
	var windunit=System.Gadget.Settings.read("myWindUnit");
	var nbwinds=4;
	for (var i=1;i<nbwinds+1;i++) {
		if ($('libUnitsWind'+i).getAttribute('value')==windunit) {
			$('alarm1Unit').innerHTML=$('libUnitsWind'+i).innerHTML;
			break;
		}
	}
}
function updateWavesUnit(object) {
  System.Gadget.Settings.write("myWavesUnit",object.value);
  
  var alarm=parseFloat(System.Gadget.Settings.read("myWaveAlarm"));
	if (alarm) {
		if  (object.value=="m") {
			alarm=feet2meters(alarm);
		} else {
			alarm=meters2feet(alarm);
		}
		System.Gadget.Settings.write("myWaveAlarm",alarm);
		$('alarm2Field').value=alarm;
	}	
  var waveunit=object.value;
	var nbwaves=2;
	for (var i=1;i<nbwaves+1;i++) {
		if ($('libUnitsWaves'+i).getAttribute('value')==waveunit) {
			$('alarm2Unit').innerHTML=$('libUnitsWaves'+i).innerHTML;
			break;
		}
	}	
}
function updateTempUnit(object) {
  System.Gadget.Settings.write("myTempUnit",object.value);
  var alarm=parseFloat(System.Gadget.Settings.read("myTempAlarm"));
	if (alarm) {
		if (object.value=="fahrenheit") {
			alarm=celcius2farenheit(alarm);
		} else {
			alarm=farenheit2celcius(alarm);
		}
		System.Gadget.Settings.write("myTempAlarm",alarm);
		$('alarm4Field').value=alarm;
	}	
  var tempunit=object.value;
	var nbtemp=2;
	for (var i=1;i<nbtemp+1;i++) {
		if ($('libUnitsTemp'+i).getAttribute('value')==tempunit) {
			$('alarm4Unit').innerHTML=$('libUnitsTemp'+i).innerHTML;
			break;
		}
	}
}

/*functions to set default values when user selects an alarm*/

function checkAlarm1(object) {
		if (object.checked==false) {
			$('alarm1Field').value='';
			System.Gadget.Settings.write("myWindAlarm","");
		} else {
			$('alarm1Field').value=5;
      System.Gadget.Settings.write("myWindAlarm",5);
		}

}
function checkAlarm2(object) {
		if (object.checked==false) {
			$('alarm2Field').value='';
			System.Gadget.Settings.write("myWaveAlarm","");
		} else {
			$('alarm2Field').value=2;
      System.Gadget.Settings.write("myWaveAlarm",2);
		}
}function checkAlarm3(object) {
		if (object.checked==false) {
			$('alarm3Field').value='';
			System.Gadget.Settings.write("myWavePeriodAlarm","");
		} else {
			$('alarm3Field').value=12;
      System.Gadget.Settings.write("myWavePeriodAlarm",12);
		}
}function checkAlarm4(object) {
		if (object.checked==false) {
			$('alarm4Field').value='';
			System.Gadget.Settings.write("myTempAlarm","");
		} else {
			$('alarm4Field').value=20;
      System.Gadget.Settings.write("myTempAlarm",20);
		}
}


/*functions to verify and store values the user types for alarm*/

function updateAlarm1(object) {
		if (object.value==''||parseFloat(object.value)==0) {
			$('alarm1Check').checked=false;
			System.Gadget.Settings.write("myWindAlarm","");
		} else {
			$('alarm1Check').checked=true;
			System.Gadget.Settings.write("myWindAlarm",object.value);
		}
}
function updateAlarm2(object) {
		if (object.value==''||parseFloat(object.value)==0) {
			$('alarm2Check').checked=false;
			System.Gadget.Settings.write("myWaveAlarm","");
		} else {
			$('alarm2Check').checked=true;
			System.Gadget.Settings.write("myWaveAlarm",object.value);
		}
}
function updateAlarm3(object) {
		if (object.value==''||parseFloat(object.value)==0) {
			$('alarm3Check').checked=false;
			System.Gadget.Settings.write("myWavePeriodAlarm","");
		} else {
			$('alarm3Check').checked=true;
			System.Gadget.Settings.write("myWavePeriodAlarm",object.value);
		}
}
function updateAlarm4(object) {
		if (object.value==''||parseFloat(object.value)==0) {
			$('alarm4Check').checked=false;
			System.Gadget.Settings.write("myTempAlarm","");
		} else {
			$('alarm4Check').checked=true;
			System.Gadget.Settings.write("myTempAlarm",object.value);
		}
}

/*
functions do display the different parts of the back
*/

function displaySpotPrefs() {
	if ($('libSpotPrefs_content').style.display=="none") {
	  if ($('libSpotPrefs_content').innerHTML=='') {

	    if (currentSpotList) {
        drawSpotList(currentSpotList);
      } else {
        getSpotListMD5();
      }
       
    }
		$('libSpotPrefs_content').style.display="block";
		$('libParamsPrefs_content').style.display="none";
		$('libParamsUnits_content').style.display="none";
		$('libParamsAlarm_content').style.display="none";
    $('arrowPrefs1').src="arrowForecastDown.png";
		$('arrowPrefs2').src="arrowForecastRight.png";
		$('arrowPrefs3').src="arrowForecastRight.png";
		$('arrowPrefs4').src="arrowForecastRight.png";
	} else {
		$('libSpotPrefs_content').style.display="none";
		$('arrowPrefs1').src="arrowForecastRight.png";
	}
}
function displayParamsPrefs() {
	if ($('libParamsPrefs_content').style.display=="none") {
		$('libSpotPrefs_content').style.display="none";
		$('libParamsPrefs_content').style.display="block";
		$('libParamsUnits_content').style.display="none";
		$('libParamsAlarm_content').style.display="none";
		$('arrowPrefs1').src="arrowForecastRight.png";
		$('arrowPrefs2').src="arrowForecastDown.png";
		$('arrowPrefs3').src="arrowForecastRight.png";
		$('arrowPrefs4').src="arrowForecastRight.png";
	} else {
		$('libParamsPrefs_content').style.display="none";
		$('arrowPrefs2').src="arrowForecastRight.png";	
	}
}
function displayUnitsPrefs() {
	if ($('libParamsUnits_content').style.display=="none") {
		$('libSpotPrefs_content').style.display="none";
		$('libParamsPrefs_content').style.display="none";
		$('libParamsUnits_content').style.display="block";
		$('libParamsAlarm_content').style.display="none";
		$('arrowPrefs1').src="arrowForecastRight.png";
		$('arrowPrefs2').src="arrowForecastRight.png";
		$('arrowPrefs3').src="arrowForecastDown.png";
		$('arrowPrefs4').src="arrowForecastRight.png";
	} else {
		$('libParamsUnits_content').style.display="none";
		$('arrowPrefs3').src="arrowForecastRight.png";	
	}
}
function displayAlarmPrefs() {
	if ($('libParamsAlarm_content').style.display=="none") {
		$('libSpotPrefs_content').style.display="none";
		$('libParamsPrefs_content').style.display="none";
		$('libParamsUnits_content').style.display="none";
		$('libParamsAlarm_content').style.display="block";
		$('arrowPrefs1').src="arrowForecastRight.png";
		$('arrowPrefs2').src="arrowForecastRight.png";
		$('arrowPrefs3').src="arrowForecastRight.png";
		$('arrowPrefs4').src="arrowForecastDown.png";
	} else {
		$('libParamsAlarm_content').style.display="none";
		$('arrowPrefs4').src="arrowForecastRight.png";
	}
}




